Project class

Inheritance

Constructors

Project({required String name, required String type, String? id})
Project.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
Object identification
getter/setter pairinherited
name String
final
parent SynrgClass?
Parent class, used for cascade save
getter/setter pairinherited
props List<Object?>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

copyWith({String? id, String? name, String? type}) Project
delete() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save() Future<void>
save function, persists the changes in FireStore
override
toMap() Map<String, dynamic>
Mapper function, used by indexer to parse data
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited