SynrgColors class

Constructors

SynrgColors({required Color brand, required MaterialColor primary, required MaterialAccentColor primaryAccent, required MaterialColor secondary, required MaterialAccentColor secondaryAccent, required MaterialColor tertiary, required MaterialAccentColor tertiaryAccent, required Color background, required Color cardBackground, required Color shadow, required Color highlights, required Color titleTextColor, required Color subtitleTextColor, required Color bodyTextColor, required Color highlightTextColor, required Color success, required Color error, required Color warning, required Color info, required Color confirm, required Color loading, required Color borderColor, required Color disabledColor, required Color textOnPrimary, required Color textOnSecondary, required Color textOnTertiary, required Color linkColor, required Color overlayColor, required Color dividerColor, required Color inputFieldColor, required Color placeholderTextColor, required Color hoverColor, required Color pressedColor, required Color focusColor})
SynrgColors.blue()
SynrgColors.green()
SynrgColors.red()
SynrgColors.yellow()

Properties

background Color
UI
final
bodyTextColor Color
final
borderColor Color
Additional UI Colors
final
brand Color
Pallet
final
cardBackground Color
final
confirm Color
final
disabledColor Color
final
dividerColor Color
final
error Color
final
focusColor Color
final
hashCode int
The hash code for this object.
no setterinherited
highlights Color
final
highlightTextColor Color
final
hoverColor Color
final
info Color
final
inputFieldColor Color
final
linkColor Color
final
loading Color
final
overlayColor Color
final
placeholderTextColor Color
final
pressedColor Color
final
primary MaterialColor
final
primaryAccent MaterialAccentColor
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary MaterialColor
final
secondaryAccent MaterialAccentColor
final
shadow Color
final
subtitleTextColor Color
final
success Color
Alerts Colors
final
tertiary MaterialColor
final
tertiaryAccent MaterialAccentColor
final
textOnPrimary Color
final
textOnSecondary Color
final
textOnTertiary Color
final
titleTextColor Color
Text Colors
final
warning Color
final

Methods

copyWith({Color? brand, MaterialColor? primary, MaterialAccentColor? primaryAccent, MaterialColor? secondary, MaterialAccentColor? secondaryAccent, MaterialColor? tertiary, MaterialAccentColor? tertiaryAccent, Color? background, Color? cardBackground, Color? shadow, Color? highlights, Color? titleTextColor, Color? subtitleTextColor, Color? bodyTextColor, Color? highlightTextColor, Color? success, Color? error, Color? warning, Color? confirm, Color? info, Color? loading, Color? borderColor, Color? disabledColor, Color? textOnPrimary, Color? textOnSecondary, Color? textOnTertiary, Color? linkColor, Color? overlayColor, Color? dividerColor, Color? inputFieldColor, Color? placeholderTextColor, Color? hoverColor, Color? pressedColor, Color? focusColor}) SynrgColors
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited