SynrgRemoteConfig class

A Firebase Remote Config wrapper

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetchAndActivate() Future<void>
Fetches the latest parameters and activates them
getBool(String key) bool
Gets a boolean value from Remote Config
getDouble(String key) double
Gets a double value from Remote Config
getInt(String key) int
Gets an integer value from Remote Config
getString(String key) String
Gets a string value from Remote Config
initialize({Map<String, dynamic>? defaultValues}) Future<void>
Initializes Remote Config with default values and fetches parameters
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance SynrgRemoteConfig
Provides a global access point to the SynrgRemoteConfig instance
no setter