SynrgSize class abstract

Constructors

SynrgSize()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

x1 → const double
BaseSize
x2 → const double
x3 → const double
x5 → const double
x8 → const double
x13 → const double
x025 → const double
x050 → const double
x075 → const double